<?php

// Load theme options
$victorianxmas_theme_options = get_option('victorianxmas_theme_options');

// Load theme options page
require_once(get_template_directory() . '/library/vx-theme-options.php');

// Theme setup
if( ! function_exists( 'victorianxmas_theme_setup' ) ):
function victorianxmas_theme_setup() {
	global $victorianxmas_theme_options;

	// Load language files
	load_theme_textdomain( 'victorianxmas', get_template_directory() . '/langs' );
	$locale = get_locale();
	$locale_file = get_template_directory() . "/langs/$locale.php";
	if( is_readable( $locale_file ) ) require_once( $locale_file );

	// add theme support
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );

	set_post_thumbnail_size( get_option('thumbnail_size_w'), get_option('thumbnail_size_h') );

	add_editor_style();

	// Remove inline gallery css
	add_filter( 'use_default_gallery_style', '__return_false' );

	// Set content width
	if( ! isset( $content_width ) ) $content_width = 955;

	// Add accordion menu
	if( !is_admin() && ( !isset($victorianxmas_theme_options['accordion']) || $victorianxmas_theme_options['accordion'] == 'yes' ) ) add_action('init', 'victorianxmas_init_accordion');

	// Add thickbox
	if( !is_admin() && ( !isset($victorianxmas_theme_options['thickbox']) || $victorianxmas_theme_options['thickbox'] == 'yes') ) {
		add_action('template_redirect', 'victorianxmas_thickbox_init');
		add_action('wp_footer', 'victorianxmas_load_tb_fix');
		add_action('wp_print_styles', 'victorianxmas_add_custom_thickbox_style');
	}

	// Set up custom post-thumbnail sizes
	if( isset($victorianxmas_theme_options['pt_width']) && $victorianxmas_theme_options['pt_width'] > 0 ) $pt_width = $victorianxmas_theme_options['pt_width'];
	else $pt_width = 200;
	if( isset($victorianxmas_theme_options['pt_height']) && $victorianxmas_theme_options['pt_height'] > 0 ) $pt_height = $victorianxmas_theme_options['pt_height'];
	else $pt_height = 200;
	if( isset($victorianxmas_theme_options['pt_crop']) && $victorianxmas_theme_options['pt_crop'] == 'hard' ) add_image_size( 'custom', $pt_width, $pt_height, true );
	else add_image_size( 'custom', $pt_width, $pt_height );

	// Set up custom post excerpt
	function victorianxmas_excerpt_length() {
		global $victorianxmas_theme_options;
		if( isset($victorianxmas_theme_options['custom_excerpt']) && $victorianxmas_theme_options['custom_excerpt'] > 0 ) return $victorianxmas_theme_options['custom_excerpt'];
		else return 100;
	}
	add_filter('excerpt_length', 'victorianxmas_excerpt_length');

	$victorianxmas_bg_defaults = array(
		'default-color' => '48583e',
		'default-image' => '%s/images/bg.jpg'
	);
	add_theme_support( 'custom-background', $victorianxmas_bg_defaults );

	$victorianxmas_header_defaults = array(
		'default-image' => '%s/images/header.jpg',
		'default-text-color' => 'f0e2b3',
		'width' => apply_filters( 'victorianxmas_header_image_width', 793 ),
		'height' => apply_filters( 'victorianxmas_header_image_height', 160 ),
		'wp-head-callback' => 'victorianxmas_theme_custom_header_style',
		'admin-head-callback' => 'victorianxmas_theme_admin_header_style',
	);
	add_theme_support( 'custom-header', $victorianxmas_header_defaults );
}
endif;
add_action( 'after_setup_theme', 'victorianxmas_theme_setup' );

// wp_title filter
if ( ! function_exists( 'victorianxmas_filter_wp_title' ) ) :
function victorianxmas_filter_wp_title( $old_title, $sep, $sep_location ) {
    $left_sep = ( $sep_location != 'right' ? ' ' . $sep . ' ' : '' );
    $right_sep = ( $sep_location != 'right' ? '' : ' ' . $sep . ' ' );

    if( is_category() ) $page_type = $left_sep . 'Category' . $right_sep;
    elseif( is_tag() ) $page_type = $left_sep . 'Tag' . $right_sep;
    elseif( is_author() ) $page_type = $left_sep . 'Author' . $right_sep;
    elseif( is_archive() || is_date() ) $page_type = $left_sep . 'Archives'. $right_sep;
    else $page_type = '';

    if( get_query_var( 'paged' ) ) $page_num = $left_sep. get_query_var( 'paged' ) . $right_sep; // on index
    elseif( get_query_var( 'page' ) ) $page_num = $left_sep . get_query_var( 'page' ) . $right_sep; // on single
    else $page_num = '';

    if( !is_feed() ) return get_bloginfo( 'name' ) . $page_type . $old_title . $page_num;
    else return $old_title;
}
endif;
add_filter( 'wp_title', 'victorianxmas_filter_wp_title', 10, 3 );

// Enqueue CSS & browser-specific JS
if (!function_exists( 'victorianxmas_style' ) ) :
function victorianxmas_style() {
	global $is_IE;
	wp_register_style('print-style', get_stylesheet_directory_uri() . '/print.css', array(), '', 	'print' );
	wp_enqueue_style( 'print-style' );
	if( $is_IE ) {
		wp_register_script('iefocus', get_template_directory_uri() . '/focus.js');
		wp_enqueue_script( 'iefocus' );
	}
}
endif;
add_action('wp_enqueue_scripts', 'victorianxmas_style');

// Add special body classes based on browser
if (!function_exists( 'victorianxmas_browser_body_class' ) ) :
function victorianxmas_browser_body_class($classes) {
	global $is_gecko, $is_IE, $is_opera, $is_safari, $is_chrome, $is_iphone;
	if( $is_gecko ) $classes[] = 'gecko';
	elseif( $is_IE ) $classes[] = 'ie';
	elseif( $is_opera ) $classes[] = 'opera';
	elseif( $is_safari ) $classes[] = 'safari';
	elseif( $is_chrome ) $classes[] = 'chrome';
	elseif( $is_iphone ) $classes[] = 'iphone';
	else $classes[] = 'unknown';
	return $classes;
}
endif;
add_filter('body_class', 'victorianxmas_browser_body_class' );

if(!function_exists('victorianxmas_widgets_init')) :
function victorianxmas_widgets_init() {
	register_sidebar(array(
		'name'=> __('Main Sidebar', 'victorianxmas'),
		'id' => 'vx_main',
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
}
endif;
add_action( 'widgets_init', 'victorianxmas_widgets_init' );

// Enqueue comments script
if ( !function_exists( ' victorianxmas_enqueue_comment_reply_script' ) ):
function victorianxmas_enqueue_comment_reply_script() {
	if ( is_singular() && ( comments_open() && get_option( 'thread_comments' ) ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
endif;
add_action( 'comment_form_before', 'victorianxmas_enqueue_comment_reply_script' );

// add custom menu support
if( function_exists( 'register_nav_menu' ) && !function_exists( 'victorianxmas_register_menus' )) :
function victorianxmas_register_menus() {
	register_nav_menu( 'sidebar', __( 'Sidebar', 'victorianxmas' ) );
}
add_action( 'init', 'victorianxmas_register_menus' );
endif;

// Accordion menu setup
if( !function_exists( 'victorianxmas_init_accordion' ) ) :
function victorianxmas_init_accordion() {
	wp_enqueue_script('victorianxmas-accordion',
    get_template_directory_uri() . '/library/vx-accordion-menu.js',
	 array('jquery'),
	'3.0.2'
	);
}
endif;

// Thickbox setup
if( !function_exists( 'victorianxmas_thickbox_init' ) ) :
function victorianxmas_thickbox_init() {
	if (wp_attachment_is_image() ) add_thickbox();
}
endif;
if( !function_exists( 'victorianxmas_load_tb_fix' ) ) :
function victorianxmas_load_tb_fix() {
	if( is_attachment() ) :?>
<script type="text/javascript">tb_pathToImage = "'<?php echo home_url();?>/wp-includes/js/thickbox/loadingAnimation.gif";tb_closeImage = "<?php echo home_url();?>/wp-includes/js/thickbox/tb-close.png";</script>
	<?php endif;
}
endif;
if( !function_exists( 'victorianxmas_add_custom_thickbox_style' ) ) :
function victorianxmas_add_custom_thickbox_style() {
	$css_file = get_stylesheet_directory() . '/library/vx-thickbox.css';
	$css_url = get_stylesheet_directory_uri() . '/library/vx-thickbox.css';
	if ( file_exists($css_file) && is_attachment() ) {
		wp_register_style('vx-thickbox', $css_url, '', '', 'screen');
		wp_enqueue_style('vx-thickbox');
	}
}
endif;

if( ! function_exists( 'victorianxmas_adminbar_adjust' ) ):
function victorianxmas_adminbar_adjust() {
	if ( !is_user_logged_in() )  return;
	global $current_user;
	get_currentuserinfo();
	if( _get_admin_bar_pref( 'front', $current_user->ID) ) :?>
<style type="text/css">
#girl {top:39px;}
#top-sprig {top:128px;}
</style>
	<?php endif;
}
endif;
add_action('wp_head', 'victorianxmas_adminbar_adjust');

// Configure home link in wp_page_menu
if( !function_exists( 'victorianxmas_show_home' ) ) :
function victorianxmas_show_home( $args ) {
	$args['show_home'] = true;
	return $args;
}
endif;
add_filter( 'wp_page_menu_args', 'victorianxmas_show_home' );

// Set up a proper &hellip;for post extracts
if( !function_exists( 'victorianxmas_proper_hellip' ) ) :
function victorianxmas_proper_hellip($more) {
	return '&hellip;';
}
endif;
add_filter('excerpt_more', 'victorianxmas_proper_hellip');

// Create decent attachment links
if( !function_exists( 'victorianxmas_attachment_link' ) ) :
function victorianxmas_attachment_link($id) {
	// grab file extension
	$bits = explode('.',get_attached_file($id));
	$ext = '.'.$bits[count($bits)-1].' format';
	// get the icon link
	$icon_link = wp_get_attachment_link($id,'thumbnail',false,true);
	// get the text link
	$text_link = wp_get_attachment_link($id,'',false,false);
	// get the filesize in kilobytes
	if(@filesize(get_attached_file($id))) {
		 $filesize = ceil(filesize(get_attached_file($id))/1024).'K';
		 return $icon_link. ' '.$text_link .' <small>(' .$ext .' ' . $filesize .')</small>';
	}
	else return $icon_link . ' ' . $text_link .' <small>(' . $ext . ')</small>';
}
endif;

/* victorianxmas_enhanced_cat_list
*  Echoes the wp_list_categories output with extra class applied to the topmost parent category.
*  Relies on etheme_top_cats()
* @param string $curr_cat: Current Category ID
* @param string $catlist: Ouput from wp_list_categories
* @param string Optional $extra_class: Additonal class to be added to the li element. Defaults to 'current-cat-ancestor'.
*
**/
if( !function_exists( 'victorianxmas_enhanced_cat_list' ) ) :
function victorianxmas_enhanced_cat_list($curr_cat_id,$catlist, $extra_class='current-cat-ancestor') {
	$top_cats = etheme_top_cats();
	foreach( $top_cats as $top_cat) {
		if( cat_is_ancestor_of($top_cat, $curr_cat_id) ) {
			$cat_ancestor_class = 'cat-item-'. $top_cat;
			$amended_class = $cat_ancestor_class . ' ' . $extra_class;
			break;
		}
		else $cat_ancestor_class = '';
	}
	if( $cat_ancestor_class != '' && stristr( $catlist, $cat_ancestor_class) ) $new_catlist = str_replace($cat_ancestor_class, $amended_class, $catlist );
	else $new_catlist = $catlist;
	echo $new_catlist;
}
endif;

// Get ids for all top level (parent) categories
// Used by victorianxmas_enhanced_cat_list
if( !function_exists( 'victorianxmas_top_cats' ) ) :
function victorianxmas_top_cats() {
	$toplevel = array();
	$allcats = get_terms('category', 'orderby=name&hide_empty=0');
	foreach( $allcats as $cat ) {
		if( $cat->parent == 0) $toplevel[] = $cat->term_id;
	}
	return $toplevel;
}
endif;

// Get archive date
if( !function_exists( 'victorianxmas_get_archive_date' ) ) :
function victorianxmas_get_archive_date() {
	if (is_day()) $this_archive = get_the_time('j F Y');
	elseif (is_month()) $this_archive = get_the_time('F Y');
	else $this_archive = get_the_time('Y');
	return $this_archive;
}
endif;

// Custom comment form fields
if( !function_exists( 'victorianxmas_theme_comment_fields' ) ) :
	function victorianxmas_theme_comment_fields($fields) {
		$commenter = wp_get_current_commenter();
		$req = get_option('require_name_email');
		if( $req ) $reqd = '<span class="required">' . __('*', 'victorianxmas') . '</span>';

		$fields['author'] = '<p class="comment-form-author"><label class="text" for="author">' . __( 'Name', 'victorianxmas' ) . $reqd . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>';

		$fields['email'] = '<p class="comment-form-email"><label class="text" for="email">' . __( 'Email', 'victorianxmas' ) . $reqd . '</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" />' . '</p>';

		$fields['url']   = '<p class="comment-form-url"><label class="text" for="url">' . __( 'Website', 'victorianxmas') . '</label>' . '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

		return $fields;
	}
endif;
add_filter('comment_form_default_fields','victorianxmas_theme_comment_fields');

// Custom comment form arguments
if( ! function_exists( 'victorianxmas_theme_comment_form_args' ) ) :
	function victorianxmas_theme_comment_form_args($user_identity, $post_id, $req) {
		global $victorianxmas_theme_options;
		$args = array(
			'comment_notes_before' => '<p class="comment-notes"><label for="author">' . ( $req ? __( ' Required fields are marked ', 'victorianxmas') . '<span class="required">' . __('*', 'victorianxmas') . '</span><br />' : '' ) . __( 'Your email address will <em>never</em> be published or shared.', 'victorianxmas' ) . '</label></p>',

			'logged_in_as' => '<p class="logged-in-as"><label for="comment">' . sprintf( __( 'Logged in as <a href="%s">%s</a>. <a href="%s" title="Log out of this account">Log out?</a></label></p>', 'victorianxmas' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ),

			'comment_field' => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun', 'victorianxmas' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8"></textarea></p>',
			'label_submit'=>'Submit Reply', 'victorianxmas'
		);

		if(!isset($victorianxmas_theme_options['display_kses']) || $victorianxmas_theme_options['display_kses'] == 'yes') $args['comment_notes_after']  = '<p class="form-allowed-tags"><label for="comment">' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s', 'victorianxmas' ), ' <code>' . allowed_tags() . '</code>' ) . '</label></p>';
		else $args['comment_notes_after'] = '';

		return $args;
	}
endif;

// Make sure we always have a post/page title
if( !function_exists( 'victorianxmas_correct_missing_title' ) ) :
function victorianxmas_correct_missing_title( $title ) {
	if( $title == '' ) $title = __('No Title', 'victorianxmas');
	return $title;
}
endif;
add_filter( 'the_title', 'victorianxmas_correct_missing_title' );

// Amend post password form
if( !function_exists ('victorianxmas_password_form') ) :
function victorianxmas_password_form() {
	global $post;
	$label = 'pwbox-'.(empty($post->ID) ? rand() : $post->ID);
	$output = '<div class="password-form">
	<p class="protected-text">' . __('This post is password protected. To view it, please enter your password below:', 'victorianxmas') . '</p>
	<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
	<p><label for="' . $label . '">' . __('Password:', 'victorianxmas') . ' </label> <input name="post_password" id="' . $label . '" type="password" size="20" /> <input type="submit" name="Submit" value="' . esc_attr__('Submit', 'victorianxmas') . '" /></p></form></div>';
	return $output;
}
endif;
add_filter('the_password_form','victorianxmas_password_form');

// Amend password protected standard excerpt
if( !function_exists ('victorianxmas_password_excerpt') ) :
function victorianxmas_password_excerpt($output) {
	global $post;
	if( post_password_required($post) ) $output = '<p class="pwd-protected">' . __('This is a password protected post.', 'victorianxmas') . '</p>';
	return $output;
}
endif;
add_filter('the_excerpt','victorianxmas_password_excerpt');

/* Custom background callback for site display */
if( ! function_exists( 'victorianxmas_custom_background_cb' ) ) :
function victorianxmas_custom_background_cb() {
	$background = get_background_image();
	$color = get_background_color();
	if( ! $background && ! $color ) return;
	$style = $color ? "background-color: #$color;" : '';
	if( $background ) {
		$image = " background-image: url('$background');";

		$repeat = get_theme_mod( 'background_repeat', 'repeat-y' );
		if( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) ) $repeat = 'repeat-y';
		$repeat = " background-repeat: $repeat;";

		$position = get_theme_mod( 'background_position_x', 'left' );
		if( ! in_array( $position, array( 'center', 'right', 'left' ) ) ) $position = 'left';
		$position = " background-position: $position top;";

		$attachment = get_theme_mod( 'background_attachment', 'fixed' );
		if( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) ) $attachment = 'fixed';
		$attachment = " background-attachment: $attachment;";

		$style .= $image . $repeat . $position . $attachment;

		if( $background != BACKGROUND_IMAGE ) $inner_body = '';
		else $inner_body = 'background:url(' . BACKGROUND_IMAGE_RIGHT . ') repeat-y top right fixed;';
	}
	else {
		$style .= 'background-image:none;';
		$inner_body = '';
	}
?>
<style type="text/css">
body{ <?php echo trim( $style ); ?> }
#inner-body {<?php echo $inner_body;?>}
</style>
<?php
}
endif;

// output header image & text CSS
if( !function_exists( 'victorianxmas_theme_custom_header_style' ) ) :
function victorianxmas_theme_custom_header_style() {
	echo '<style type="text/css" media="screen">'."\n";
	if( get_header_image() != '' ) echo '#header {background-image:url(' . get_header_image() . ');}';
	else echo '#header {background-image:none;}';
	if( get_header_textcolor() == 'blank' ) echo '#header h1 {position:absolute;top:-5000px;left:-5000px;}';
	else echo '#header,#header h1,#header h1 a {color:#' . get_header_textcolor() . ';}';
	echo "\n</style>\n\n";
}
endif;

// Style header customisation in the Admin area
if( !function_exists( 'victorianxmas_theme_admin_header_style' ) ) :
function victorianxmas_theme_admin_header_style() {
?>
<style type="text/css">
#headimg {
	height:160px;
	padding:0;
	margin:0;
	color:#F0E2B3;
	background-color:#782724;
	background-repeat:no-repeat;
	background-position:center top;
	min-width:793px;
}
#headimg h1 {
	margin:0;
	padding:45px 0 0;
	font-size:2.5em;
	line-height:1em;
	font-style:italic;
	text-align:center;
	font-family:georgia,palatino,times,'times new roman',serif;
	letter-spacing:.02em;
}
#headimg a {
	text-decoration:none;
}
#headimg a:hover,#headimg a:active,#headimg a:focus {
	text-decoration:underline;
}
#headimg #desc {
	display:none;
}
</style>
<?php
}
endif;
