<?php

// Set options array
function victorianxmas_all_theme_options() {
	$vx_theme_options = array(
		'accordion' => array(
			'label' => __('Collapsing sub-menus (vertical sidebar)', 'victorianxmas'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Enabled', 'victorianxmas' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Disabled', 'victorianxmas' )
				)
			)
		),
		'pt_width' => array(
			'label' => __('Featured image width', 'victorianxmas'),
			'type' => 'text',
			'default' => '150',
			'maxlength' => 3,
			'numeric' => 1
		),
		'pt_height' => array(
			'label' => __('Featured image height', 'victorianxmas'),
			'type' => 'text',
			'default' => '150',
			'maxlength' => 3,
			'numeric' => 1
		),
		'pt_crop' => array(
			'label' => __('Featured image cropping', 'victorianxmas'),
			'type' => 'radio',
			'default' => 'soft',
			'choices' => array(
				'1' => array(
					'value' => 'soft',
					'label' => __( 'Soft (proportional)', 'victorianxmas' )
				),
				'2' => array(
					'value' => 'hard',
					'label' => __( 'Hard (fixed)', 'victorianxmas' )
				)
			)
		),
		'home_tag_cloud' => array(
			'label' => __('Display tag cloud on main posts page', 'victorianxmas'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Yes', 'victorianxmas' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'No', 'victorianxmas' )
				)
			)
		),
		'image_thickbox' => array(
			'label' => __('Use thickbox for attachment images', 'victorianxmas'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Yes', 'victorianxmas' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'No', 'victorianxmas' )
				)
			)
		),
		'custom_excerpt' => array(
			'label' => __('Post Excerpt Length', 'victorianxmas'),
			'type' => 'text',
			'default' => '100',
			'maxlength' => 3,
			'numeric' => 1
		),
		'display_kses' => array(
			'label' => __('Allowed Tags (comment form)', 'victorianxmas'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Display', 'victorianxmas' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Hide', 'victorianxmas' )
				)
			)
		)
	);
	return apply_filters( 'victorianxmas_default_theme_options', $vx_theme_options );
}

// White list theme options
function victorianxmas_options_init() {
	register_setting( 'victorianxmas', 'victorianxmas_theme_options', 'victorianxmas_options_validate' );
}
add_action( 'admin_init', 'victorianxmas_options_init' );

// Add theme options page
function victorianxmas_options_add_page() {
	add_theme_page( __( 'Theme Options', 'victorianxmas' ), __( 'Theme Options', 'victorianxmas' ), 'edit_theme_options', 'victorianxmas', 'victorianxmas_options_do_page' );
}
add_action('admin_menu', 'victorianxmas_options_add_page');

function victorianxmas_options_enqueue_style() {
	wp_enqueue_style('victorianxmas_options_style', get_template_directory_uri() . '/library/vx-theme-options.css', '', false, 'screen');
}
add_action('admin_print_styles-appearance_page_victorianxmas', 'victorianxmas_options_enqueue_style');

// Theme options form
function victorianxmas_options_do_page() {
	global  $pagenow;
	$vx_theme_options = victorianxmas_all_theme_options();
	$updated = false;
	if ( isset( $_REQUEST['updated'] ) || isset( $_REQUEST['settings-updated'] ) ) $updated = true;?>

	<div class="wrap">
	<?php screen_icon(); echo "<h2>" .  wp_get_theme() . "</h2>";
	include 'vx-donate.php';?>

	<?php if ( $updated == true ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your theme options have been saved', 'victorianxmas'); ?></strong></p></div>
	<?php endif; ?>

	<form method="post" action="options.php" id="victorianxmas_options"><div>
	<?php settings_fields( 'victorianxmas' ); ?>
	<?php $stored_options = get_option('victorianxmas_theme_options');?>

	<?php $option_name = 'accordion';
	victorianxmas_options_do_radio( $vx_theme_options[$option_name], $stored_options, $option_name);?>

	<fieldset class="pt-size">
	<legend><?php _e('Featured image size', 'victorianxmas'); ?></legend>
	<?php $option_name = 'pt_width';
	victorianxmas_options_do_text( $vx_theme_options[$option_name], $stored_options, $option_name);?><br />
	<?php $option_name = 'pt_height';
	victorianxmas_options_do_text( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<?php $option_name = 'pt_crop';
	victorianxmas_options_do_radio( $vx_theme_options[$option_name], $stored_options, $option_name);?>

	<?php $option_name = 'home_tag_cloud';
	victorianxmas_options_do_radio( $vx_theme_options[$option_name], $stored_options, $option_name);?>

	<?php $option_name = 'image_thickbox';
	victorianxmas_options_do_radio( $vx_theme_options[$option_name], $stored_options, $option_name);?>

	<fieldset class="custom-teaser">
	<legend><?php _e('Post Teaser', 'victorianxmas'); ?></legend>
	<?php $option_name = 'custom_excerpt';
	victorianxmas_options_do_text( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<?php $option_name = 'display_kses';
	victorianxmas_options_do_radio( $vx_theme_options[$option_name], $stored_options, $option_name);?>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'victorianxmas') ?>" /></p>

	</div></form>
</div>
	<?php
}

// sort inputs for display
function victorianxmas_options_sort($option_input, $stored_options, $name) {
	switch ($option_input['type']) {
		case 'radio':
		victorianxmas_options_do_radio($option_input['choices'], $stored_options, $name, $option_input['default']);
		break;

		default:
		break;
	}
}

// Radio button display
function victorianxmas_options_do_radio($option, $stored_options, $name) {
	$radio_options = $option['choices'];
	$default = $option['default'];
	if ( ! isset( $checked ) ) $checked = '';?>
	<fieldset class="<?php echo $name;?>">
	<legend><?php echo $option['label']; ?></legend>
	<?php foreach ( $radio_options as $option ) {
		if ( isset( $stored_options[$name] ) ) {
			if( $stored_options[$name] == $option['value'] ) $checked = 'checked="checked"';
			else $checked = '';
		}
		else{
			if ( $option['value']  ==  $default ) $checked = 'checked="checked"';
			else $checked = '';
		}?>
	<label class="description" for="<?php echo $name;?>_<?php echo esc_attr( $option['value'] ); ?>"><input type="radio" id="<?php echo $name;?>_<?php echo esc_attr( $option['value'] ); ?>" name="victorianxmas_theme_options[<?php echo $name;?>]" value="<?php echo esc_attr( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label>
		<?php
	}
	echo '</fieldset>';
}

// Text input display
function victorianxmas_options_do_text($setting, $stored_options, $name) {
	if( isset( $stored_options[$name] ) ) {
		if( $setting['numeric'] == 1 ) {
			if( ctype_digit( $stored_options[$name] ) ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
		else {
			if( $stored_options[$name] != '' ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
	}
	else $current_value = $setting['default'];
	?>
	<label class="description text" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <input type="text" id="<?php echo $name;?>" name="victorianxmas_theme_options[<?php echo $name;?>]" maxlength="<?php echo $setting['maxlength'];?>" value="<?php echo $current_value;?>" />
	<?php
}

// Sanitize and validate inputs
function victorianxmas_options_validate( $input ) {
	$new_input = array();
	$all_theme_options = victorianxmas_all_theme_options();
	$theme_option_names = array_keys($all_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $theme_option_name['type'];
		switch ($option_type) {

			case 'radio':
			if( $all_theme_options[$theme_option_name]['default'] == 'yes' ) $new_input[$theme_option_name] = ( $input[$theme_option_name] == 'yes' ? 'yes' : 'no' );

			case 'text':
			$new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $theme_option_name['default'];
	}
	return $new_input;
}

/* THEME CUSTOMIZER */

// Add theme options to Customizer
function victorianxmas_customize_register($wp_customize) {
	$all_victorianxmas_theme_options = victorianxmas_all_theme_options();

	 //Add section
	$wp_customize->add_section( 'victorianxmas_theme_options', array(
		'title' => __( 'Theme Options', 'victorianxmas' ),
		'priority'       => 200,
	) );

	foreach( $all_victorianxmas_theme_options as $option_key => $option_values ) {
		// Add settings
		$option_name = 'victorianxmas_theme_options[' . $option_key . ']';
		$wp_customize->add_setting( $option_name, array(
			'default' => $option_values['default'],
			'type'  => 'option',
			'capability' => 'edit_theme_options',
		) );
		// Add radio controls
		if( $option_values['type'] == 'radio' ) {
			$choices = array();
			foreach( $option_values['choices'] as $option ) {
				$ckey = $option['value'];
				$cvalue = $option['label'];
				$choices[ $ckey ] = $cvalue;
			}
			$wp_customize->add_control( $option_name, array(
				'label' => $option_values['label'],
				'section' => 'victorianxmas_theme_options',
				'settings' => $option_name,
				'type' => 'radio',
				'choices' => $choices,
			) );
		}
		// Add text controls
		if( $option_values['type'] == 'text' ) {
			$wp_customize->add_control( $option_name, array(
				'label' => $option_values['label'],
				'section' => 'victorianxmas_theme_options',
				'settings' => $option_name,
				'type' => 'text',
			) );
		}
	}
	if ( $wp_customize->is_preview() ) add_action('customize_controls_print_styles', 'victorianxmas_options_enqueue_style');
}
add_action( 'customize_register', 'victorianxmas_customize_register' );
